@@ -2,8 +2,6 @@ import json
 from pathlib import Path
 
 import yaml
-from yaml import SafeLoader
-
 from octadocs.octiron.types import Context
 from octadocs.octiron.yaml_extensions import convert_dollar_signs
 
@@ -17,5 +15,5 @@ def context_from_json(path: Path) -> Context:
 def context_from_yaml(path: Path) -> Context:
     """Load context.json file and return its content."""
     with path.open('r') as context_file:
-        raw_data = yaml.load(context_file, Loader=SafeLoader)
+        raw_data = yaml.load(context_file, Loader=yaml.SafeLoader)
         return convert_dollar_signs(raw_data)
